@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11628 2019-06-11 15:07:25Z Lavender $
+# $Id: __init__.py 11660 2019-07-21 13:24:58Z Trista $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2019-06-11 23:07:25 +0800 (週二, 11 六月 2019) $
-# $Revision: 11628 $
+# $Author: Trista $ (last)
+# $Date: 2019-07-21 21:24:58 +0800 (週日, 21 七月 2019) $
+# $Revision: 11660 $
 
 import os
 import sys
@@ -102,6 +102,7 @@ def attachSettings(settingsDict):
         'robots',
         'django_gravatar',
         'captcha',
+        'Zephyrus.instagram',
     ]
 
     if ZEPHYRUS_BLOG_ENABLE:
