@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11601 2019-06-01 19:27:05Z Lavender $
+# $Id: models.py 11641 2019-06-19 07:33:01Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-06-02 04:27:05 +0900 (週日, 02 六月 2019) $
-# $Revision: 11601 $
+# $Date: 2019-06-19 15:33:01 +0800 (週三, 19 六月 2019) $
+# $Revision: 11641 $
 
 import datetime
 
@@ -61,7 +61,8 @@ class RecentResponsePlugin(CMSPlugin):
 
 class Comment(models.Model):
     url = models.CharField(
-        verbose_name=_("URL"), max_length=400, editable=False, null=True)
+        verbose_name=_("URL"), max_length=400, 
+        editable=False, null=True, db_index=True)
     
     user = models.ForeignKey(
         settings.AUTH_USER_MODEL, null=True, blank=True, verbose_name=_("User"),)
